"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FeedGenerator = void 0;
const utils_1 = require("@vuepress/utils");
const path_1 = require("path");
const feed_1 = require("./feed");
const options_1 = require("./options");
const page_1 = require("./page");
const utils_2 = require("./utils");
class FeedGenerator {
    constructor(app, options) {
        this.app = app;
        this.options = options;
        this.feedMap = Object.fromEntries(Object.entries(options).map(([localePath, localeOptions]) => {
            return [
                localePath,
                new feed_1.Feed({
                    channel: (0, options_1.getFeedChannelOption)(app, localeOptions, localePath),
                    links: (0, options_1.getFeedLinks)(app, localeOptions),
                }),
            ];
        }));
    }
    addPages(localePath) {
        const feed = this.feedMap[localePath];
        const localeOption = this.options[localePath];
        const { count: feedCount = 100, filter = ({ frontmatter, filePathRelative }) => !(frontmatter["home"] ||
            !filePathRelative ||
            frontmatter["article"] === false ||
            frontmatter["feed"] === false), sorter = (pageA, pageB) => (0, utils_2.compareDate)(pageA.data.git?.createdTime
            ? new Date(pageA.data.git?.createdTime)
            : pageA.frontmatter.date, pageB.data.git?.createdTime
            ? new Date(pageB.data.git?.createdTime)
            : pageB.frontmatter.date), } = localeOption;
        const pages = this.app.pages
            .filter((page) => page.pathLocale === localePath)
            .filter(filter)
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            .sort(sorter)
            .slice(0, feedCount);
        let count = 0;
        for (const page of pages) {
            const item = new page_1.FeedPage(this.app, localeOption, page, feed).getFeedItem();
            if (item) {
                feed.addItem(item);
                count += 1;
            }
        }
        utils_2.logger.succeed(`added ${utils_1.chalk.cyan(`${count} page(s)`)} as feed item(s) in route ${utils_1.chalk.cyan(localePath)}`);
    }
    async generateFeed() {
        const { dest } = this.app.dir;
        await Promise.all(Object.entries(this.options).map(async ([localePath, localeOptions]) => {
            // current locale has valid output
            if (localeOptions.atom || localeOptions.json || localeOptions.rss) {
                const feed = this.feedMap[localePath];
                const { atomOutputFilename, jsonOutputFilename, rssOutputFilename } = (0, options_1.getFilename)(localeOptions, localePath);
                this.addPages(localePath);
                // generate atom files
                if (localeOptions.atom) {
                    await utils_1.fs.ensureDir((0, path_1.dirname)(dest(atomOutputFilename)));
                    await utils_1.fs.outputFile(dest(atomOutputFilename), feed.atom());
                    utils_2.logger.succeed(`Atom feed file generated and saved to ${utils_1.chalk.cyan(atomOutputFilename)}`);
                }
                // generate json files
                if (localeOptions.json) {
                    await utils_1.fs.ensureDir((0, path_1.dirname)(dest(jsonOutputFilename)));
                    await utils_1.fs.outputFile(dest(jsonOutputFilename), feed.json());
                    utils_2.logger.succeed(`JSON feed file generated and saved to ${utils_1.chalk.cyan(jsonOutputFilename)}`);
                }
                // generate rss files
                if (localeOptions.rss) {
                    await utils_1.fs.ensureDir((0, path_1.dirname)(dest(rssOutputFilename)));
                    await utils_1.fs.outputFile(dest(rssOutputFilename), feed.rss());
                    utils_2.logger.succeed(`RSS feed file generated and saved to ${utils_1.chalk.cyan(rssOutputFilename)}`);
                }
            }
        }));
    }
}
exports.FeedGenerator = FeedGenerator;
//# sourceMappingURL=generator.js.map