"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.injectLinkstoHead = void 0;
const options_1 = require("./options");
const utils_1 = require("./utils");
const injectLinkstoHead = (app, options) => {
    const { base } = app.options;
    const { siteData } = app;
    const localePaths = Object.keys(options);
    // there is only one language, so we append it to siteData
    if (localePaths.length === 1) {
        const { atomOutputFilename, jsonOutputFilename, rssOutputFilename } = (0, options_1.getFilename)(options["/"]);
        const { atom, json, rss, hostname } = options["/"];
        const getHeadItem = (name, fileName, type) => {
            return [
                "link",
                {
                    rel: "alternate",
                    type,
                    href: (0, utils_1.resolveUrl)(hostname, base, fileName),
                    title: `${siteData.title || siteData.locales["/"]?.title || ""} ${name} Feed`,
                },
            ];
        };
        // ensure head exists
        if (!siteData.head)
            siteData.head = [];
        // add atom link
        if (atom)
            siteData.head.push(getHeadItem("Atom", atomOutputFilename, "application/atom+xml"));
        // add json link
        if (json)
            siteData.head.push(getHeadItem("JSON", jsonOutputFilename, "application/json"));
        // add rss link
        if (rss)
            siteData.head.push(getHeadItem("RSS", rssOutputFilename, "application/rss+xml"));
    }
    // there are multiple languages, so we should append to page
    else
        app.pages.forEach((page) => {
            const { pathLocale } = page;
            const localeOptions = options[pathLocale];
            if (localePaths.includes(pathLocale)) {
                const { atomOutputFilename, jsonOutputFilename, rssOutputFilename } = (0, options_1.getFilename)(localeOptions, pathLocale);
                const getHeadItem = (name, fileName, type) => {
                    return [
                        "link",
                        {
                            rel: "alternate",
                            type,
                            href: (0, utils_1.resolveUrl)(localeOptions.hostname, base, fileName),
                            title: `${siteData.locales[pathLocale]?.title ||
                                siteData.title ||
                                siteData.locales["/"]?.title ||
                                ""} ${name} Feed`,
                        },
                    ];
                };
                // ensure head exists
                if (!page.frontmatter.head)
                    page.frontmatter.head = [];
                // add atom link
                if (localeOptions.atom)
                    page.frontmatter.head.push(getHeadItem("Atom", atomOutputFilename, "application/atom+xml"));
                // add json link
                if (localeOptions.json)
                    page.frontmatter.head.push(getHeadItem("JSON", jsonOutputFilename, "application/json"));
                // add rss link
                if (localeOptions.rss)
                    page.frontmatter.head.push(getHeadItem("RSS", rssOutputFilename, "application/rss+xml"));
            }
        });
};
exports.injectLinkstoHead = injectLinkstoHead;
//# sourceMappingURL=injectHead.js.map