"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFeedLinks = exports.getFilename = exports.getFeedChannelOption = exports.getFeedOptions = exports.checkOutput = exports.ensureHostName = void 0;
const shared_1 = require("@vuepress/shared");
const vuepress_shared_1 = require("vuepress-shared");
const utils_1 = require("./utils");
const ensureHostName = (options) => {
    // make sure hostname do not end with `/`
    if (options.hostname) {
        options.hostname = (0, shared_1.isLinkHttp)(options.hostname)
            ? (0, shared_1.removeEndingSlash)(options.hostname)
            : `https://${(0, shared_1.removeEndingSlash)(options.hostname)}`;
        return true;
    }
    return false;
};
exports.ensureHostName = ensureHostName;
const checkOutput = (options) => 
// some locales request output
(options.locales &&
    Object.entries(options.locales).some(([, { atom, json, rss }]) => atom || json || rss)) ||
    // root option requsts output
    Boolean(options.atom || options.json || options.rss);
exports.checkOutput = checkOutput;
const getFeedOptions = ({ siteData }, options) => Object.fromEntries(Object.keys({
    // root locale must exists
    // eslint-disable-next-line @typescript-eslint/naming-convention
    "/": {},
    ...siteData.locales,
}).map((localePath) => [
    localePath,
    {
        // default values
        filter: ({ frontmatter, filePathRelative }) => !(frontmatter["home"] ||
            !filePathRelative ||
            frontmatter["article"] === false ||
            frontmatter["feed"] === false),
        sorter: (pageA, pageB) => (0, utils_1.compareDate)(pageA.data.git?.createdTime
            ? new Date(pageA.data.git?.createdTime)
            : pageA.frontmatter.date, pageB.data.git?.createdTime
            ? new Date(pageB.data.git?.createdTime)
            : pageB.frontmatter.date),
        ...options,
        ...options.locales?.[localePath],
        // make sure hostname is not been overrided
        hostname: options.hostname,
    },
]));
exports.getFeedOptions = getFeedOptions;
const getFeedChannelOption = (app, options, localePath = "") => {
    const { base } = app.options;
    const { title, description, lang, locales } = app.siteData;
    const { hostname, icon, image } = options;
    const author = options.channel?.author?.name;
    const defaultChannelOpion = {
        title: locales[localePath]?.title || title || locales["/"]?.title || "",
        link: (0, utils_1.resolveUrl)(hostname, base, localePath),
        description: locales[localePath]?.description ||
            description ||
            locales["/"]?.description ||
            "",
        language: locales[localePath]?.lang || lang,
        copyright: author ? `Copyright by ${author}` : "",
        pubDate: new Date(),
        lastUpdated: new Date(),
        ...(icon ? { icon } : {}),
        ...(image ? { image } : {}),
        ...(author ? { author: { name: author } } : {}),
    };
    return (0, vuepress_shared_1.deepAssign)(defaultChannelOpion, options.channel || {});
};
exports.getFeedChannelOption = getFeedChannelOption;
const getFilename = (options, prefix = "/") => ({
    atomOutputFilename: `${(0, shared_1.removeLeadingSlash)(prefix)}${options.atomOutputFilename || "atom.xml"}`,
    jsonOutputFilename: `${(0, shared_1.removeLeadingSlash)(prefix)}${options.jsonOutputFilename || "feed.json"}`,
    rssOutputFilename: `${(0, shared_1.removeLeadingSlash)(prefix)}${options.rssOutputFilename || "rss.xml"}`,
});
exports.getFilename = getFilename;
const getFeedLinks = ({ options: { base } }, options) => {
    const { hostname } = options;
    const { atomOutputFilename, jsonOutputFilename, rssOutputFilename } = (0, exports.getFilename)(options);
    return {
        atom: (0, utils_1.resolveUrl)(hostname, base, atomOutputFilename),
        json: (0, utils_1.resolveUrl)(hostname, base, jsonOutputFilename),
        rss: (0, utils_1.resolveUrl)(hostname, base, rssOutputFilename),
    };
};
exports.getFeedLinks = getFeedLinks;
//# sourceMappingURL=options.js.map